package Test::Mock::LWP::UserAgent::ButAwesome;
{
  $Test::Mock::LWP::UserAgent::ButAwesome::VERSION = '0.003';
}
# git description: v0.002-1-g6b28b25


use strict;
use warnings;

1;
__END__

=pod

=head1 NAME

Test::Mock::LWP::Dispatch::ButAwesome - Renamed to Test::LWP::UserAgent

=head1 DESCRIPTION

This module has been renamed to L<Test::LWP::UserAgent>.

=head1 AUTHOR

Karen Etheridge <ether@cpan.org>

=head1 COPYRIGHT

This software is copyright (c) 2012 by Karen Etheridge.

=head1 LICENSE

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

